@@ -1,23 +1,11 @@
-/* This file is part of the KDE libraries
+/*
+    This file is part of the KDE libraries
 
-   Copyright (c) 2000 Carsten Pfeiffer <pfeiffer@kde.org>
-                 2000 Stefan Schimanski <1Stein@gmx.de>
-                 2000,2001,2002,2003,2004 Dawit Alemayehu <adawit@kde.org>
+    SPDX-FileCopyrightText: 2000 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2000 Stefan Schimanski <1Stein@gmx.de>
+    SPDX-FileCopyrightText: 2000, 2001, 2002, 2003, 2004 Dawit Alemayehu <adawit@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License (LGPL) as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KCOMPLETIONBOX_H
@@ -208,11 +196,12 @@ protected:
      */
     QRect calculateGeometry() const;
 
+#if KCOMPLETION_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * @deprecated since 5.0, use resizeAndReposition instead.
      */
-#ifndef KCOMPLETION_NO_DEPRECATED
-    KCOMPLETION_DEPRECATED void sizeAndPosition()
+    KCOMPLETION_DEPRECATED_VERSION(5, 0, "Use KCompletionBox::resizeAndReposition()")
+    void sizeAndPosition()
     {
         resizeAndReposition();
     }
